aboutsummaryrefslogtreecommitdiffhomepage
path: root/config.def.h
diff options
context:
space:
mode:
Diffstat (limited to 'config.def.h')
-rw-r--r--config.def.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/config.def.h b/config.def.h
index 169bcdd..047b5d1 100644
--- a/config.def.h
+++ b/config.def.h
@@ -30,7 +30,9 @@ static const char *colorname[] = {
"cyan",
"white",
- /* more colors can be added to use with DefaultXX */
+ [255] = 0,
+
+ /* more colors can be added after 255 to use with DefaultXX */
"#cccccc",
"#333333",
};
@@ -39,8 +41,8 @@ static const char *colorname[] = {
foreground, background, cursor, unfocused cursor */
#define DefaultFG 7
#define DefaultBG 0
-#define DefaultCS 16
-#define DefaultUCS 17
+#define DefaultCS 256
+#define DefaultUCS 257
/* Special keys (change & recompile st.info accordingly)
Keep in mind that kpress() in st.c hardcodes some keys.